--- loncom/publisher/lonpubdir.pm 2011/10/21 18:04:51 1.128
+++ loncom/publisher/lonpubdir.pm 2014/04/06 19:39:04 1.151
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Construction Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.128 2011/10/21 18:04:51 www Exp $
+# $Id: lonpubdir.pm,v 1.151 2014/04/06 19:39:04 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -33,7 +33,6 @@ use strict;
use Apache::File;
use File::Copy;
use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
use Apache::loncommon();
use Apache::lonhtmlcommon();
use Apache::londiff();
@@ -47,12 +46,12 @@ sub handler {
my $r=shift;
- # Validate access to the construction space and get username@domain.
+ # Validate access to the construction space and get username:domain.
my $uname;
my $udom;
- ($uname,$udom)=&Apache::loncacc::constructaccess($r->uri);
+ ($uname,$udom)=&Apache::lonnet::constructaccess($r->uri);
unless (($uname) && ($udom)) {
return HTTP_NOT_ACCEPTABLE;
}
@@ -80,15 +79,23 @@ sub handler {
my $numdir = 0;
my $numres = 0;
+ # Retrieving value for sortby from QUERY_STRING
+ &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sortby']);
+
+ # Default sort by 'Name'
+ if (! exists($env{'form.sortby'})) {
+ $env{'form.sortby'} = 'filename';
+ }
+
# Start off the directory table.
$r->print(&Apache::loncommon::start_data_table()
.&Apache::loncommon::start_data_table_header_row()
.'
'.&mt('Type').' '
.''.&mt('Actions').' '
- .''.&mt('Name').' '
+ .''.&mt('Name').' ▼ '
.''.&mt('Title').' '
.''.&mt('Status').' '
- .''.&mt('Last Modified').' '
+ .''.&mt('Last Modified').' ▼ '
.&Apache::loncommon::end_data_table_header_row()
);
@@ -96,24 +103,51 @@ sub handler {
my $dirptr=16384; # Mask indicating a directory in stat.cmode.
opendir(DIR,$fn);
+ my $filehash = {};
+ my $sortby = $env{'form.sortby'};
my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
foreach my $filename (@files) {
- my ($cdev,$cino,$cmode,$cnlink,
- $cuid,$cgid,$crdev,$csize,
- $catime,$cmtime,$cctime,
- $cblksize,$cblocks)=stat($fn.'/'.$filename);
-
- my $extension='';
- if ($filename=~/\.(\w+)$/) { $extension=$1; }
- if ($cmode&$dirptr) {
- putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
- } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
- putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
- $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
- } else {
- # "hidden" extension and not a directory, so hide it away.
+ next if ($filename eq '.DS_Store');
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ # If you want to sort by "last modified", we need to make this hash.
+ if ($sortby eq 'cmtime') {
+ $filehash->{ $filename } = {"cmtime" => $cmtime,};
}
- }
+ # Otherwise sort by name. Don't bother with filehash. Continue printing contents.
+ else {
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ }
+ }
+ };
+
+ # Sorting files by "last modified" if that's what you selected
+ if ($sortby eq 'cmtime') {
+ my @sorted_files = sort {
+ $filehash->{$b}->{$sortby} <=> $filehash->{$a}->{$sortby}
+ } (keys(%{$filehash}));
+ foreach my $filename (@sorted_files) {
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ };
+ };
+ };
+
closedir(DIR);
$r->print(&Apache::loncommon::end_data_table()
@@ -135,37 +169,44 @@ sub handler {
sub startpage {
my ($r, $uname, $udom, $thisdisfn) = @_;
- my $currdir = '/priv/'.$uname.$thisdisfn;
&Apache::loncommon::content_type($r,'text/html');
$r->send_http_header;
- my $formaction='/priv/'.$uname.$thisdisfn.'/';
+ my $formaction='/priv'.$thisdisfn.'/';
$formaction=~s|/+|/|g;
&Apache::lonhtmlcommon::store_recent('construct',$formaction,$formaction);
&Apache::lonhtmlcommon::clear_breadcrumbs();
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
- 'href' => &Apache::loncommon::authorspace(),
+ 'text' => 'Authoring Space',
+ 'href' => &Apache::loncommon::authorspace($formaction),
});
# breadcrumbs (and tools) will be created
# in start_page->bodytag->innerregister
- $env{'request.noversionuri'}=$currdir.'/';
- $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+ $env{'request.noversionuri'}=$formaction;
+ $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+ my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+ my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+ my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+ $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
$r->print(&Apache::loncommon::head_subbox(
- &Apache::loncommon::CSTR_pageheader(1)));
+ ''
+ .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+ .'
'
+ .&Apache::loncommon::CSTR_pageheader()));
my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
- my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+ my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
my $newname = &mt('New Name');
my $pubdirscript=(<
top.document.title = '$esc_thisdisfn/ - $doctitle';
// Store directory location for menu bar to find
-parent.lastknownpriv='/~$uname$esc_thisdisfn/';
+parent.lastknownpriv='/priv$esc_thisdisfn/';
// Confirmation dialogues
@@ -320,7 +361,7 @@ sub dircontrols {
$lt{'prnt'}
$lt{'dedr'}
-
+
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
#